interface RecursiveStringObject {
  [modifier: string]: string | RecursiveStringObject;
}

type CSSAttributeValue = string | (string | RecursiveStringObject)[];

/**
 * Tagged template macro function combining Tailwind classes
 * @example "tw" => tw`p-2 text-center`
 */
export interface TailwindFunction {
  (strings: TemplateStringsArray): string;
  (...args: (string | RecursiveStringObject)[]): string;
}

/**
 * Tagged template macro function compiling Tailwind styles
 * @example "tws" => tws`p-2 text-center` // { padding: 2, textAlign: "center" }
 */
export interface TailwindStyleFunction {
  (strings: TemplateStringsArray): TailwindStyleFunctionReturn;
  (...args: (string | RecursiveStringObject)[]): TailwindStyleFunctionReturn;
}

export const tw: TailwindFunction;
export const tws: TailwindStyleFunction;

type TailwindStyleFunctionReturn = Config extends { tws: infer T } ? T : never;

/**
 * Type configuration for the Tailwind style macro
 * @example
 *
 * ```ts
 * declare module "_tailwind_lib/macro" {
 *   interface Config {
 *     tws: React.CSSProperties;
 *   }
 * }
 * ```
 */
// eslint-disable-next-line @typescript-eslint/no-empty-interface
export interface Config {}
